Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1401)

Unified Diff: gdb/serial.h

Issue 124383005: GDB 7.6.50 (Closed) Base URL: http://git.chromium.org/native_client/nacl-gdb.git@upstream
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « gdb/ser-unix.c ('k') | gdb/serial.c » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: gdb/serial.h
diff --git a/gdb/serial.h b/gdb/serial.h
index b16406222957bcfc4ced7707e032e9e8011c74cd..7a97e282a0bc2d363254296dbf39e7ef6da8d530 100644
--- a/gdb/serial.h
+++ b/gdb/serial.h
@@ -1,6 +1,5 @@
/* Remote serial support interface definitions for GDB, the GNU Debugger.
- Copyright (C) 1992-1996, 1998-2001, 2004-2012 Free Software
- Foundation, Inc.
+ Copyright (C) 1992-2013 Free Software Foundation, Inc.
This file is part of GDB.
@@ -105,10 +104,10 @@ enum serial_rc {
extern int serial_readchar (struct serial *scb, int timeout);
/* Write LEN chars from STRING to the port SCB. Returns 0 for
success, non-zero for failure. */
-extern int serial_write (struct serial *scb, const char *str, int len);
+extern int serial_write (struct serial *scb, const void *buf, size_t count);
/* Write a printf style string onto the serial port. */
@@ -205,13 +204,6 @@ typedef void (serial_event_ftype) (struct serial *scb, void *context);
extern void serial_async (struct serial *scb,
serial_event_ftype *handler, void *context);
-/* Provide direct access to the underlying FD (if any) used to
- implement the serial device. This interface is clearly
- deprecated. Will call internal_error() if the operation isn't
- applicable to the current serial device. */
-
-extern int deprecated_serial_fd (struct serial *scb);
-
/* Trace/debug mechanism.
serial_debug() enables/disables internal debugging.
@@ -264,7 +256,7 @@ struct serial_ops
void (*close) (struct serial *);
int (*fdopen) (struct serial *, int fd);
int (*readchar) (struct serial *, int timeout);
- int (*write) (struct serial *, const char *str, int len);
+ int (*write) (struct serial *, const void *buf, size_t count);
/* Discard pending output */
int (*flush_output) (struct serial *);
/* Discard pending input */
@@ -105,10 +104,10 @@ enum serial_rc {
extern int serial_readchar (struct serial *scb, int timeout);
-/* Write LEN chars from STRING to the port SCB. Returns 0 for
+/* Write COUNT bytes from BUF to the port SCB. Returns 0 for
success, non-zero for failure. */
« no previous file with comments | « gdb/ser-unix.c ('k') | gdb/serial.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698